@@ -2,7 +2,7 @@ use v5.34;
 use warnings;
 use Object::Pad 0.73;
 
-class Archive::SCS 1.06;
+class Archive::SCS 1.07;
 
 use stable 0.031 'isa';
 
@@ -15,8 +15,9 @@ use Path::Tiny 0.054 'path';
 use Archive::SCS::Directory;
 use Archive::SCS::HashFS;
 use Archive::SCS::HashFS2;
+use Archive::SCS::Zip;
 
-field @formats = qw( HashFS2 HashFS Directory );
+field @formats = qw( HashFS2 HashFS Directory Zip );
 
 field @mounts;
 field %entries;
@@ -38,7 +39,7 @@ method set_formats {
 
 method format_module ($path) {
   my $header = '';
-  if ($path->is_file) {
+  if (! $path->is_dir) {
     open my $fh, '<:raw', $path or croak
       sprintf "%s: $!", $path->basename;
     read $fh, $header, 8 or croak
@@ -65,9 +66,9 @@ method mount ($mountable) {
     sprintf "%s: Already mounted", $basename;
 
   my $mount = $mountable->mount;
+  $mount->read_dir_tree(@ROOTS);
   push @mounts, $mount;
   push $entries{$_}->@*, $mount for my @entries = $mount->entries;
-  $mount->read_dir_tree(@ROOTS);
 
   return $mount;
 }
@@ -281,6 +282,8 @@ are the following:
 
 =item * L<Archive::SCS::HashFS2>
 
+=item * L<Archive::SCS::Zip>
+
 =back
 
 =head2 unmount
